==> zio-aws-opsworkscm_2.12-5.17.157.2-sources.jar: zio/aws/opsworkscm/model/ListTagsForResourceResponse.scala <==
package zio.aws.opsworkscm.model
import zio.ZIO
import zio.aws.opsworkscm.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    tags: Option[Iterable[zio.aws.opsworkscm.model.Tag]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.opsworkscm.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opsworkscm.model.ListTagsForResourceResponse =
      zio.aws.opsworkscm.model.ListTagsForResourceResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tags: Option[List[zio.aws.opsworkscm.model.Tag.ReadOnly]]
    def nextToken: Option[NextToken]
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.opsworkscm.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ) extends zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly {
    override val tags: Option[List[zio.aws.opsworkscm.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.opsworkscm.model.Tag.wrap(item)
          }.toList
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.opsworkscm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ): zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-opsworkscm_2.12-5.17.295.16-sources.jar: zio/aws/opsworkscm/model/ListTagsForResourceResponse.scala <==
package zio.aws.opsworkscm.model
import zio.ZIO
import zio.aws.opsworkscm.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    tags: Optional[Iterable[zio.aws.opsworkscm.model.Tag]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.opsworkscm.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opsworkscm.model.ListTagsForResourceResponse =
      zio.aws.opsworkscm.model.ListTagsForResourceResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tags: Optional[List[zio.aws.opsworkscm.model.Tag.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.opsworkscm.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ) extends zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly {
    override val tags: Optional[List[zio.aws.opsworkscm.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.opsworkscm.model.Tag.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.opsworkscm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opsworkscm.model.ListTagsForResourceResponse
  ): zio.aws.opsworkscm.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}
